@@ -6,9 +6,10 @@
 #'
 #' @param port_name String. Name of the new portfolio
 #' @param port_desc String. Portfolio description
+#' @param quiet Should the response be printed to the console
 #' @inheritParams AccountSummary
 #' @export
-CreatePortfolio<- function(port_name, port_desc, LC_CRED=NULL){
+CreatePortfolio<- function(port_name, port_desc, LC_CRED=NULL, quiet=T){
 
     LC_CRED<-CheckCred(LC_CRED)
 
@@ -16,9 +17,13 @@ CreatePortfolio<- function(port_name, port_desc, LC_CRED=NULL){
 
 
 
-    params<- list("aid" = LC_CRED$investorID,
+    params<- list("actorId" = LC_CRED$investorID,
                   "portfolioName" = port_name,
                   "portfolioDescription" = port_desc)
 
-    LC_POST(postURL, params, LC_CRED$key)
-}
+    resp<- LC_POST(postURL, params, LC_CRED$key)
+    
+    if (!quiet && !is.null(resp$errors)) {
+        message(sapply(resp$errors, function(x) x$message))
+        }
+    }
