@@ -6,6 +6,7 @@
 #' @param query parameters to be added to and encoded into the URL
 #' @param margin logical. Passed to CleanData function
 #' @return object with raw content from the API call and the GET response
+#' @keywords internal
 
 LC_GET<- function(searchURL, auth, query=NULL, margin=T){
     r<- httr::GET(searchURL,
@@ -19,7 +20,7 @@ LC_GET<- function(searchURL, auth, query=NULL, margin=T){
         }
 
     parsed<- jsonlite::fromJSON(httr::content(r, "text", encoding="UTF-8"),
-                                simplifyVector = FALSE)
+                                simplifyVector = TRUE)
 
     if (httr::http_error(r)) {
         stop(
